tlslite.integration.HTTPTLSConnection

Package tlslite :: Package integration :: Module HTTPTLSConnection |
[show private | hide private]
[frames | no frames]

## Module tlslite.integration.HTTPTLSConnection

TLS Lite + httplib.

Classes
`HTTPBaseTLSConnection` | This abstract class provides a framework for adding TLS support to httplib.
`HTTPTLSConnection` | This class extends `HTTPBaseTLSConnection` to support the common types of handshaking.

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net